#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Zaman Am"
#define MSG_CAPABILITIES "Anahtar destekleri yaplamyor"
#define MSG_CLIENT_CLOSED_CNX "Kullanc balanty kapatt"
#define MSG_CLIENT_READ_ERR "Kullancdan okuma hatas"
#define MSG_CANT_OPEN_CNX "Balant alamyor"
#define MSG_CANT_CREATE_DATA_SOCKET "Data kaps oluturulamad"
#define MSG_DEBUG_CLIENT_IS "Kullanc IP adresi"
#define MSG_SYNTAX_ERROR_IP "IP adresinde sralama hatas"
#define MSG_PORT_SUCCESSFUL "PORT komutu gerekleti"
#define MSG_ONLY_IPV4V6 "Sadece IPv4 ve IPv6 desteklenmektedir (1,2)"
#define MSG_ONLY_IPV4 "Sadece IPv4 desteklenmektedir (1)"
#define MSG_TIMEOUT_PARSER "Zaman Am - bi sonraki sefere daha hzl yazp deneyiniz"
#define MSG_LINE_TOO_LONG "Satr ok uzun"
#define MSG_LOG_OVERFLOW "Kullanc gvenli komut satr tamasna sebep oldu"
#define MSG_GOODBYE "Hoakaln. Gncellemeleriniz %llu ve indirdikleriniz %llu kbytes."
#define MSG_DEBUG_COMMAND "Komut"
#define MSG_IS_YOUR_CURRENT_LOCATION "uanki yeriniz"
#define MSG_NOT_LOGGED_IN "Giri yapamadnz"
#define MSG_AUTH_UNIMPLEMENTED "Gvenlik eklentileri tamamlanamad"
#define MSG_NO_FILE_NAME "Dosya ad yok"
#define MSG_NO_DIRECTORY_NAME "Klasr ad yok"
#define MSG_NO_RESTART_POINT "Yeniden balatma noktas yok"
#define MSG_ABOR_SUCCESS "ABOR dan nce grdkleriniz baar ile tamamland"
#define MSG_MISSING_ARG "Eksik girdi"
#define MSG_GARBAGE_FOUND "Deerden sonra gereksizlik bulundu"
#define MSG_VALUE_TOO_LARGE "Deer ok uzun"
#define MSG_IDLE_TIME "Haraketsiz bekleme sresi %lu saniye"
#define MSG_SITE_HELP "Belirtilen SITE komutu onayland"
#define MSG_BAD_CHMOD "Yanl eriim"
#define MSG_UNKNOWN_EXTENSION "bilinmeyen uzant"
#define MSG_XDBG_OK "XDBG komutu baarl, yeni debug dzeyi %d"
#define MSG_UNKNOWN_COMMAND "Bilinmeyen komut"
#define MSG_TIMEOUT_NOOP "Zaman Am (%lu saniyedir hareket olmad)"
#define MSG_TIMEOUT_DATA "Zaman Am (%lu saniyedir yeni data yok)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Zaten giri yaptnz"
#define MSG_ANY_PASSWORD "ifre yok"
#define MSG_ANONYMOUS_LOGGED "Misafir kullanc giri yapt"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Sanal FTP olarak misafir kullanc giri yapt"
#define MSG_USER_OK "Kullanc %s OK. ifreyi giriniz"
#define MSG_CANT_DO_TWICE "Bu oturumda yaplamyor"
#define MSG_UNABLE_SECURE_ANON "Gvenli Misafir FTP ayarlanmad"
#define MSG_BANDWIDTH_RESTRICTED "Trafik kullanmnz snrl"
#define MSG_NO_PASSWORD_NEEDED "ifre yok"
#define MSG_NOTRUST "zgnz, gven salayamadnz"
#define MSG_WHOAREYOU "Ltfen kim olduunuzu soyleyiniz."
#define MSG_AUTH_FAILED "Yetkiniz hatal, zgnz"
#define MSG_AUTH_TOOMANY "ok fazla yetki istei hatas"
#define MSG_NO_HOMEDIR "Ana klasrnz bulunamad - klyor"
#define MSG_NO_HOMEDIR2 "%s bulunamad veya okunamyor"
#define MSG_START_SLASH "Balang /"
#define MSG_USER_GROUP_ACCESS "Kullanc %s grup eriim salad"
#define MSG_FXP_SUPPORT "Bu sunucu FXP transferini desteklemektedir"
#define MSG_RATIO "Bakm oran %u:%u (GN/ND)"
#define MSG_CHROOT_FAILED "Gvenli chroot() ayarlanamad"
#define MSG_CURRENT_DIR_IS "OK. uanki klasr %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. uanki snrl klasr %s"
#define MSG_IS_NOW_LOGGED_IN "%s giri yapt"
#define MSG_CANT_CHANGE_DIR "Klasr deitirilemedi %s"
#define MSG_PATH_TOO_LONG "Yol ok uzun"
#define MSG_CANT_PASV "PASV komutunu IPv6 balantsnda kullanamazsnz.Yerine EPSV kullannz."
#define MSG_CANT_PASSIVE "Pasif balant alamyor"
#define MSG_PORTS_BUSY "Tm ayrlm TCP kaplar megul"
#define MSG_GETSOCKNAME_DATA "Lokal data girii tannamad"
#define MSG_GETPEERNAME "Lokal giri tannamad"
#define MSG_INVALID_IP "zgnz, yanl adres belirlenmi"
#define MSG_NO_EPSV "Ltfen EPSV destekli bir IPv6-conformant kullanc kullannz"
#define MSG_BAD_PORT "zgnz, 1024 den kk portlarla baalanamayz "
#define MSG_NO_FXP "%s balants alamyor(sadece %s)"
#define MSG_FXP "FXP transfer: %s den %s 'ye"
#define MSG_NO_DATA_CONN "Data balants yok"
#define MSG_ACCEPT_FAILED "Balant kabul edilmedi"
#define MSG_ACCEPT_SUCCESS "Data balant kabul edildi"
#define MSG_CNX_PORT_FAILED "%d kapsndan data balants alamyor"
#define MSG_CNX_PORT "%d balantsndan balanyor"
#define MSG_ANON_CANT_MKD "zgnz, misafir kullancsnn klasr oluturma yetkisi yok"
#define MSG_ANON_CANT_RMD "zgnz, misafir kullancsnn klasr silme yetkisi yok"
#define MSG_ANON_CANT_RENAME "Misafir kullancsnn dosya tama/isim deitirme yetkisi yok"
#define MSG_ANON_CANT_CHANGE_PERMS "Misafir kullancsnn izinleri deitirme yetkisi yok"
#define MSG_GLOB_NO_MEMORY "%s esnasnda bellek tamas olutu"
#define MSG_PROBABLY_DENIED "(Bu yntem muhtelemen \"zin engellendi\")"
#define MSG_GLOB_READ_ERROR "%s esnasnda  okuma hatas"
#define MSG_GLOB_NO_MATCH "%s iinde %s bulunamad"
#define MSG_CHMOD_FAILED "%s iin izinler deitirilemedi"
#define MSG_CHMOD_SUCCESS "%s iin izinler deitirildi"
#define MSG_CHMOD_TOTAL_FAILURE "zgnz, izinler deitirilemedi"
#define MSG_ANON_CANT_DELETE "Misafir kullanc dosyalar silimez"
#define MSG_ANON_CANT_OVERWRITE "Misafir kullanc varolan dosya zerine yazamaz"
#define MSG_DELE_FAILED "%s silinemiyor"
#define MSG_DELE_SUCCESS "%s%s%s%s silindi"
#define MSG_DELE_TOTAL_FAILURE "Silinen dosya yok"
#define MSG_LOAD_TOO_HIGH \
    "Balantnzdan sonra yk %3.2f . Ar yklenme esnasnda misafir ndirmelere izin veremiyoruz.\n" \
    "Bu durmda sadece gnderim izinlidir.\n"

#define MSG_OPEN_FAILURE "%s almad"
#define MSG_OPEN_FAILURE2 "Dosya alamad"
#define MSG_STAT_FAILURE "Dosya boyutu bulunamad"
#define MSG_STAT_FAILURE2 "Dosya oluturma kontrol edilemedi"
#define MSG_REST_TOO_LARGE_FOR_FILE "%lld iin yeniden balayn %lld den dosya bykll ok byk ."
#define MSG_REST_RESET "Yeniden balayn yenileme 0"
#define MSG_NOT_REGULAR_FILE "Sadece dzgn dosyalar geri alabiliriz"
#define MSG_NOT_MODERATED \
    "Bu dosya misafir kullanc tarafndan yklendi. Sistem Yneticisi\n" \
    "bunun inidirilmesi iin henz onay vermedi"
#define MSG_RATIO_DENIAL \
    "zgnz, gnderme/indirme oran %u:%u .\n" \
    "uanki gndermeniz %llu Kb ve indirmeniz %llu Kb.\n" \
    "Ltfen daha sonra tekrar deneyiniz."
#define MSG_NO_MORE_TO_DOWNLOAD "ndirme kalmad"
#define MSG_WINNER "Bilgisayar arkadanz. Bilgisayara gvenin."
#define MSG_KBYTES_LEFT "%.1f kbytes indirme"
#define MSG_ABORTED "Transferden vazgeildi"
#define MSG_DATA_WRITE_FAILED "Data balantsnda yazma srasnda hata"
#define MSG_DATA_READ_FAILED "Data balantsnda okuma srasnda hata"
#define MSG_MMAP_FAILED "Dosyadann hafzadaki yeri alamad"
#define MSG_WRITE_FAILED "Dosyaya yazma srasnda hata"
#define MSG_TRANSFER_RATE_M "%.3f saniye (burdaki l), saniyede %.2f Mbytes "
#define MSG_TRANSFER_RATE_K "%.3f saniye (burdaki l), saniyede %.2f Kbytes "
#define MSG_TRANSFER_RATE_B "%.3f saniye (burdaki l), saniyede %.2f bytes "
#define MSG_SPACE_FREE_M "Bo disk alan %.1f Mbytes "
#define MSG_SPACE_FREE_K "Bo disk alan %f Kbytes "
#define MSG_DOWNLOADED "indirildi"
#define MSG_REST_NOT_NUMERIC "REST de rakamsal paremetre gerekli"
#define MSG_REST_ASCII_STRICT "areti ASCII modda 0 ile cevaplaynz "
#define MSG_REST_ASCII_WORKAROUND "%lld Yeniden balatlyor. ASCII mod iinde"
#define MSG_REST_SUCCESS "%lld yeniden balatlyor"
#define MSG_SANITY_DIRECTORY_FAILURE "Yasak klasr ad"
#define MSG_SANITY_FILE_FAILURE "Yasak dosya ad: %s"
#define MSG_MKD_FAILURE "Klasr oluturalamad"
#define MSG_MKD_SUCCESS "Klasr baaryla oluturuldu"
#define MSG_RMD_FAILURE "Klasr kaldrlamad"
#define MSG_RMD_SUCCESS "Klasr baaryla kaldrld"
#define MSG_TIMESTAMP_FAILURE "Zaman biimi alnamad"
#define MSG_MODE_ERROR "Sadece ASCII ve binary mod desteklenmektedir"
#define MSG_CREATE_FAILURE "Dosya oluturulamad"
#define MSG_ABRT_ONLY "ABRT sadece gncelleme sresinde kullanlr"
#define MSG_UPLOAD_PARTIAL "ksmen gncelendi"
#define MSG_REMOVED "kaldrld"
#define MSG_UPLOADED "gncellendi"
#define MSG_GMTIME_FAILURE "Lokal zaman alnamad"
#define MSG_TYPE_8BIT_FAILURE "Sadece 8-bit bytelar desteklenir, 10 yanda deilim ki."
#define MSG_TYPE_UNKNOWN "Bilinmeyen TYPE"
#define MSG_TYPE_SUCCESS "TYPE uan"
#define MSG_STRU_FAILURE "Sadece D(osya) desteklenmektedir"
#define MSG_MODE_FAILURE "Ltfen S(tream) mod kullann"
#define MSG_RENAME_ABORT "nceki isim deitirmeden vazgeiliyor"
#define MSG_RENAME_RNFR_SUCCESS "RNFR kabul edildi - belirtilen yerde dosya var, "
#define MSG_FILE_DOESNT_EXIST "zgnz, dosya bulunamad"
#define MSG_RENAME_ALREADY_THERE "RENAME Hatal - belirtilen dosya ad zaten var"
#define MSG_RENAME_NORNFR "RNTO nce RNFR gerekli"
#define MSG_RENAME_FAILURE "sim Deitirme/Tama hatal"
#define MSG_RENAME_SUCCESS "Dosya ismi deitirme/tama baarl"
#define MSG_NO_SUPERSERVER "Ltfen pure-ftpd yi super-server ile altrnz (tcpserver gerekli)"
#define MSG_NO_FTP_ACCOUNT "'ftp' hesab bulunamad"
#define MSG_CONF_ERR "Konfigrasyon hatas"
#define MSG_NO_VIRTUAL_FILE "Sanal kullanc dosyas eksik"
#define MSG_ILLEGAL_THROTTLING "Azaltma iin geersiz deer"
#define MSG_ILLEGAL_TRUSTED_GID "chroot iin geersiz gid"
#define MSG_ILLEGAL_USER_LIMIT "Geersiz kullanc limiti"
#define MSG_ILLEGAL_FACILITY "Bilinmeyen olanak ad"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Bilinmeyen LDAP konfigrasyon dosyas"
#define MSG_ILLEGAL_LOAD_LIMIT "Geersiz ykleme limiti"
#define MSG_ILLEGAL_PORTS_RANGE "Geersiz kap sras"
#define MSG_ILLEGAL_LS_LIMITS "Geersiz 'ls' limiti"
#define MSG_ILLEGAL_FORCE_PASSIVE "Pasif balant iin geersiz zorunlu IP "
#define MSG_ILLEGAL_RATIO "Geersiz gncelleme/indirme oran"
#define MSG_ILLEGAL_UID_LIMIT "Geersiz uid limiti"
#define MSG_ILLEGAL_OPTION "Bilinmeyen gerek zamanl seim"
#define MSG_LDAP_MISSING_BASE "LDAP konfigrasyon dosyasnda LDAPBaseDN eksik"
#define MSG_LDAP_WRONG_PARMS "Yanl LDAP parametresi"
#define MSG_NEW_CONNECTION "%s den yeni balant"
#define MSG_WELCOME_TO "Hogeldiniz"
#define MSG_MAX_USERS "%lu kullanc (maksimum) zaten giri yapt, zgnz"
#define MSG_NB_USERS "Kullanc numaranz %u den %u kabul edildi."
#define MSG_WELCOME_TIME "Lokal zaman uan %02d:%02d. Sunucu kaps: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Sadece Misafir FTP kabul edilir"
#define MSG_RATIOS_EVERYONE "HERKES N ORAN AIK:"
#define MSG_RATIOS_ANONYMOUS "MSAFR KULLANICIYA BALI GUN/IND ORANI:"
#define MSG_RATIOS_RULE "indirme %u Mb, gncelleme %u Mb zorunlu."
#define MSG_INFO_IDLE_M "%lu dakikadan sonra hareket olmazsa balant kapanr."
#define MSG_INFO_IDLE_S "%lu saniyeden sonra hareket olmazsa balant kapanr."
#define MSG_CANT_READ_FILE "zgnz, [%s] okunamad"
#define MSG_LS_TRUNCATED "kt ksaltmas %u uygun"
#define MSG_LS_SUCCESS "Uygun toplam %u"
#define MSG_LOGOUT "k."
#define MSG_AUTH_FAILED_LOG "[%s] kullancs iin giri hatal"
#define MSG_ILLEGAL_UMASK "Geersiz umask"
#define MSG_STANDALONE_FAILED "Standalone sunucu balatlamad"
#define MSG_NO_ANONYMOUS_LOGIN "Bu zel sistem - Misafir girii olamaz"
#define MSG_ANONYMOUS_ANY_PASSWORD "ifre bo"
#define MSG_MAX_USERS_IP "Bu (%lu) IP den ok fazla balant"
#define MSG_ACTIVE_DISABLED "Aktif mod kapal"
#define MSG_TRANSFER_SUCCESSFUL "Dosya baar ile transfer edildi"
#define MSG_NO_DISK_SPACE "Disk dolu - ltfen daha sonra gncelleyiniz"
#define MSG_OUT_OF_MEMORY "Hafza Tamas"
#define MSG_ILLEGAL_TRUSTED_IP "Geersiz IP adresi"
#define MSG_NO_ASCII_RESUME "ASCII yenilenmesi gvensiz, ltfen daha nce dosyay siliniz"
#define MSG_UNKNOWN_ALTLOG "Bilinmeyen log biimi"
#define MSG_ACCOUNT_DISABLED "[%s] giriine izin yok: hesap kapal"
#define MSG_SQL_WRONG_PARMS "Yanl SQL parametresi"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Yanl SQL konfigrasyon dosyas"
#define MSG_SQL_MISSING_SERVER "SQL konfigrasyon dosyas iinde sunucu eksik"
#define MSG_SQL_DOWN "SQL sunucusu kapal grnyor"
#define MSG_ILLEGAL_QUOTA "Geersiz kota"
#define MSG_QUOTA_FILES "%llu dosya kullanm (%d%%) - yetki: %llu dosya"
#define MSG_QUOTA_SIZE "%llu Kbytes kullanm (%d%%) - yetki: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Kota am: [%s] kaydedilemedi"
#define MSG_AUTH_UNKNOWN "Bilinmeyen yetkilendirme metodu"
#define MSG_PDB_BROKEN "puredb dosyasndan indexlenme okunamad (veya eski biim algland) - pure-pw mkdb yi deneyiniz"
#define MSG_ALIASES_ALIAS "%s takma ad %s ."
#define MSG_ALIASES_UNKNOWN "Bilinmeyen takmaad %s."
#define MSG_ALIASES_BROKEN_FILE "Hasarl takma ad dosyas"
#define MSG_ALIASES_LIST "Belirtilen takma ad kullanlabilir :"
#define MSG_PERUSER_MAX "%lu den ayn kullanc kabul edemiyoruz"
#define MSG_IPV6_OK "IPv6 balants kabul edildi, Hogeldiniz."
#define MSG_TLS_INFO "TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
